@@ -2,7 +2,7 @@ use super::Optimizer;
 use crate::{
     compress::optimize::Ctx,
     mode::Mode,
-    util::{idents_used_by, make_number},
+    util::{idents_captured_by, idents_used_by, make_number},
 };
 use std::{
     collections::HashMap,
@@ -526,6 +526,18 @@ where
             }
         }
 
+        if self.ctx.executed_multiple_time {
+            if !param_ids.is_empty() {
+                let captured = idents_captured_by(body);
+
+                for param in param_ids {
+                    if captured.contains(&param.to_id()) {
+                        return false;
+                    }
+                }
+            }
+        }
+
         if !body.stmts.iter().all(|stmt| match stmt {
             Stmt::Decl(Decl::Var(VarDecl {
                 kind: VarDeclKind::Var | VarDeclKind::Let,
